@@ -15,7 +15,7 @@ use Git;
 use File::Spec;
 use base qw/Exporter/;
 
-our $VERSION     = 1.0.1;
+our $VERSION     = 1.0.2;
 our @EXPORT      = qw/git/;
 our @EXPORT_OK   = qw//;
 our %EXPORT_TAGS = ();
@@ -32,8 +32,8 @@ sub new {
         ) {
             pop @dir;
         }
-        $self->{repository} = File::Spec->catdir(@dir);
-        die "Couldn't find the git repository!\n" if !-d $self->{repository};
+        $self->{repository} = File::Spec->catdir(@dir) || '';
+        die "Couldn't find the git repository! '$self->{repository}'\n" if !-d $self->{repository};
     }
     $self->{git} = Git->repository(Directory => $self->{repository});
 
@@ -90,7 +90,7 @@ App::Git::Workflow::Repository - A basic wrapper around GIT
 
 =head1 VERSION
 
-This documentation refers to App::Git::Workflow::Repository version 1.0.1
+This documentation refers to App::Git::Workflow::Repository version 1.0.2
 
 =head1 SYNOPSIS
 
